From: fabbione@sourceware.org <fabbione@sourceware.org>
To: cluster-devel.redhat.com
Subject: [Cluster-devel] cluster/gfs-kernel/src/gfs ops_file.c
Date: 28 Jan 2008 06:36:18 -0000 [thread overview]
Message-ID: <20080128063618.27423.qmail@sourceware.org> (raw)
CVSROOT: /cvs/cluster
Module name: cluster
Changes by: fabbione at sourceware.org 2008-01-28 06:36:18
Modified files:
gfs-kernel/src/gfs: ops_file.c
Log message:
fix gfs for the removal of sendfile and helper functions
Sendfile and helper functions have been removed in 2.6.24. Migrate
to using splice_read and generic_file_splice_read helper function.
Signed-off-by: Phillip Lougher <phillip@canonical.com>
Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/cluster/gfs-kernel/src/gfs/ops_file.c.diff?cvsroot=cluster&r1=1.37&r2=1.38
--- cluster/gfs-kernel/src/gfs/ops_file.c 2008/01/24 20:54:31 1.37
+++ cluster/gfs-kernel/src/gfs/ops_file.c 2008/01/28 06:36:18 1.38
@@ -1633,13 +1633,12 @@
return gfs_lm_plock(sdp, &name, file, cmd, fl);
}
-#if 0
/**
* gfs_sendfile - Send bytes to a file or socket
* @in_file: The file to read from
* @out_file: The file to write to
* @count: The amount of data
* @offset: The beginning file offset
*
* Outputs: offset - updated according to number of bytes read
*
@@ -1647,7 +1646,7 @@
*/
static ssize_t
-gfs_sendfile(struct file *in_file, loff_t *offset, size_t count, read_actor_t actor, void __user *target)
+gfs_splice_read(struct file *in_file, loff_t *ppos, struct pipe_inode_info *pipe, size_t count, unsigned int flags)
{
struct gfs_inode *ip = get_v2ip(in_file->f_mapping->host);
struct gfs_holder gh;
@@ -1664,7 +1663,7 @@
if (gfs_is_jdata(ip))
retval = -ENOSYS;
else
- retval = generic_file_sendfile(in_file, offset, count, actor, target);
+ retval = generic_file_splice_read(in_file, ppos, pipe, count, flags);
gfs_glock_dq(&gh);
@@ -1673,7 +1672,6 @@
return retval;
}
-#endif
/**
* do_flock - Acquire a flock on a file
@@ -1802,7 +1800,7 @@
.release = gfs_close,
.fsync = gfs_fsync,
.lock = gfs_lock,
- /* .sendfile = gfs_sendfile, */
+ .splice_read = gfs_splice_read,
.flock = gfs_flock,
};
next reply other threads:[~2008-01-28 6:36 UTC|newest]
Thread overview: 15+ messages / expand[flat|nested] mbox.gz Atom feed top
2008-01-28 6:36 fabbione [this message]
-- strict thread matches above, loose matches on Subject: below --
2008-01-30 9:05 [Cluster-devel] cluster/gfs-kernel/src/gfs ops_file.c fabbione
2007-06-17 3:35 wcheng
2007-06-17 2:56 wcheng
2007-05-24 22:34 wcheng
2007-05-04 14:49 wcheng
2007-01-17 22:30 wcheng
2006-11-17 20:39 wcheng
2006-11-17 20:33 wcheng
2006-11-17 20:26 wcheng
2006-11-17 19:49 wcheng
2006-11-17 16:15 wcheng
2006-11-17 5:00 wcheng
2006-10-27 16:22 wcheng
2006-10-24 3:35 wcheng
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20080128063618.27423.qmail@sourceware.org \
--to=fabbione@sourceware.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1633,13 +1633,12 @@
/**
- * gfs_sendfile - Send bytes to a file or socket
+ * gfs_splice_read - Send bytes to a file or socket
* @in_file: The file to read from
* @out_file: The file to write to
@@ -1633,13 +1633,12 @@
* @out_file: The file to write to
* @count: The amount of data
- * @offset: The beginning file offset
+ * @ppos: The beginning file offset
*
* Outputs: offset - updated according to number of bytes read
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.